/*
 * Klogwatch, Netfilter log monitor
 *
 * Copyright (C) 2004 Nick Battle <nick.battle@freeuk.com>
 *
 * This program is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the
 * Free Software Foundation; either version 2, or (at your option) any
 * later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 */

#include <qdir.h>
#include <kglobalsettings.h>
#include <kuniqueapplication.h>
#include "klogconfig.h"
#include "debug.h"

KLogConfig::KLogConfig()
{
    file = kapp->config();
    load();
}

KLogConfig::~KLogConfig()
{
    save();
    delete file;
    me = NULL;
}

KLogConfig *KLogConfig::me;

KLogConfig *KLogConfig::getConfig()
{
    if (me == NULL)
    {
	debug("Creating config\n");
	me = new KLogConfig();
    }
    else
    {
	debug("Returning config\n");
    }

    return me;
}

void KLogConfig::load()
{
    debug("Loading config\n");

    file->setGroup("Timings");
    POLLTIME = file->readNumEntry("POLLTIME", _POLLTIME);
    PAUSETIME = file->readNumEntry("PAUSETIME", _PAUSETIME);
    SHOWTIME = file->readNumEntry("SHOWTIME", _SHOWTIME);

    file->setGroup("General");
    MINLINES = file->readNumEntry("MINLINES", _MINLINES);
    BUFFSIZE = file->readNumEntry("BUFFSIZE", _BUFFSIZE);
    COMMAND = file->readEntry("COMMAND", _COMMAND);
    FILENAME = file->readEntry("FILENAME", _FILENAME);
    SYSTRAY = file->readNumEntry("SYSTRAY", _SYSTRAY);
    TRAYALERT = file->readNumEntry("TRAYALERT", _TRAYALERT);

    QFont def = KGlobalSettings::fixedFont();
    FONT = file->readFontEntry("FONT", &def);

    debug("POLLTIME = %d\n", POLLTIME);
    debug("PAUSETIME = %d\n", PAUSETIME);
    debug("SHOWTIME = %d\n", SHOWTIME);
    debug("MINLINES = %d\n", MINLINES);
    debug("BUFFSIZE = %d\n", BUFFSIZE);
    debug("COMMAND = %s\n", COMMAND.latin1());
    debug("FILENAME = %s\n", FILENAME.latin1());
    debug("FONT = %s\n", FONT.toString().latin1());
    debug("SYSTRAY = %d\n", SYSTRAY);
    debug("TRAYALERT = %d\n", TRAYALERT);
}

void KLogConfig::save()
{
    debug("Saving config\n");
    
    file->setGroup("Timings");
    file->writeEntry("POLLTIME", POLLTIME);
    debug("Written POLLTIME = %d\n", POLLTIME);
    file->writeEntry("PAUSETIME", PAUSETIME);
    debug("Written PAUSETIME = %d\n", PAUSETIME);
    file->writeEntry("SHOWTIME", SHOWTIME); 
    debug("Written SHOWTIME = %d\n", SHOWTIME);

    file->setGroup("General");
    file->writeEntry("MINLINES", MINLINES);
    debug("Written MINLINES = %d\n", MINLINES);
    file->writeEntry("BUFFSIZE", BUFFSIZE);
    debug("Written BUFFSIZE = %d\n", BUFFSIZE);
    file->writeEntry("COMMAND", COMMAND);
    debug("Written COMMAND = %s\n", COMMAND.latin1());
    file->writeEntry("FILENAME", FILENAME);
    debug("Written FILENAME = %s\n", FILENAME.latin1());
    file->writeEntry("FONT", FONT);
    debug("Written FONT = %s\n", FONT.toString().latin1());
    file->writeEntry("SYSTRAY", SYSTRAY);
    debug("Written SYSTRAY = %d\n", SYSTRAY);
    file->writeEntry("TRAYALERT", TRAYALERT);
    debug("Written TRAYALERT = %d\n", TRAYALERT);

    file->sync();
}

void KLogConfig::defaults()
{
    debug("Setting defaults\n");
    
    POLLTIME = _POLLTIME;
    debug("Set POLLTIME = %d\n", POLLTIME);
    PAUSETIME = _PAUSETIME;
    debug("Set PAUSETIME = %d\n", PAUSETIME);
    SHOWTIME = _SHOWTIME;
    debug("Set SHOWTIME = %d\n", SHOWTIME);

    file->setGroup("General");
    MINLINES = _MINLINES;
    debug("Set MINLINES = %d\n", MINLINES);
    BUFFSIZE = _BUFFSIZE;
    debug("Set BUFFSIZE = %d\n", BUFFSIZE);
    COMMAND = _COMMAND;
    debug("Set COMMAND = %s\n", COMMAND.latin1());
    FILENAME = _FILENAME;
    debug("Set FILENAME = %s\n", FILENAME.latin1());
    SYSTRAY = _SYSTRAY;
    debug("Set SYSTRAY = %d\n", SYSTRAY);
    TRAYALERT = _TRAYALERT;
    debug("Set TRAYALERT = %d\n", TRAYALERT);
    FONT = KGlobalSettings::fixedFont();
    debug("Set FONT = %s\n", FONT.toString().latin1());
}

// eof
