/*
 * Klogwatch, Netfilter log monitor
 *
 * Copyright (C) 2004 Nick Battle <nick.battle@freeuk.com>
 *
 * This program is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the
 * Free Software Foundation; either version 2, or (at your option) any
 * later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 */

#include "klogitem.h"
#include "debug.h"
#include <qpainter.h>

KLogItem::KLogItem(QListView *listbox, const KLogLine *line) :
	QListViewItem(listbox)
{
    this->line = line;
    packet = line->getPacket();

    this->setText(0, packet->getTime());
    this->setText(1, (packet->getProto()).lower());
    this->setText(2, packet->getSrcIP());
    this->setText(3, packet->getDstPort());
    this->setText(4, (packet->getFlags()).lower());

    srcIpNum[0] = ((packet->getSrcIP()).section('.', 0, 0)).toInt();
    srcIpNum[1] = ((packet->getSrcIP()).section('.', 1, 1)).toInt();
    srcIpNum[2] = ((packet->getSrcIP()).section('.', 2, 2)).toInt();
    srcIpNum[3] = ((packet->getSrcIP()).section('.', 3, 3)).toInt();

    dstPortNum = packet->getDstPortNum();

    isNew = true;
}

void KLogItem::paintCell(QPainter *p, const QColorGroup &cg,int column, int width, int alignment)
{
  if (isNew)
  {
    QFont font(p->font());
    font.setBold(true);
    p->setFont(font);
  }
  QListViewItem::paintCell(p, cg, column, width, alignment);
}

const KLogIP *KLogItem::getPacket(void) const
{
    return packet;
}

int KLogItem::compare(QListViewItem *i, int col, bool ascending ) const
{


    if (col == 0) { //sort by packet number, not clock time
      if ( packetNumber < ((KLogItem*)i)->packetNumber )
        return -1;
      else if ( packetNumber > ((KLogItem*)i)->packetNumber )
        return 1;
      else
        return 0;
    }

    else if (col == 2) {  //sort ip address numerically
      for (int count=0; count < 4; count++) {
        if (srcIpNum[count] < ((KLogItem*)i)->srcIpNum[count])
          return -1;
        else if (srcIpNum[count] > ((KLogItem*)i)->srcIpNum[count])
          return 1;
      }
      return 0;
    }

    else if (col == 3) { //sort destination port numerically
      if ( dstPortNum < ((KLogItem*)i)->dstPortNum )
        return -1;
      else if ( dstPortNum > ((KLogItem*)i)->dstPortNum )
        return 1;
      else
        return 0;
    }

    else // return normal compare for all other columns
      return QString::localeAwareCompare( key(col, ascending), i->key(col, ascending) );
}

KLogItem::~KLogItem()
{
    debug("Destroy KLogItem\n");
    delete line;	// delete's packet too
}

