/*
 * Klogwatch, Netfilter log monitor
 *
 * Copyright (C) 2004 Nick Battle <nick.battle@freeuk.com>
 *
 * This program is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the
 * Free Software Foundation; either version 2, or (at your option) any
 * later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 */

#ifndef KLOGLIST_H
#define KLOGLIST_H

#include <qtimer.h>
#include <qtextstream.h>
#include <qthread.h>
#include <qlistview.h>
#include <kprinter.h>
#include "qtlist.h"
#include "klogtail.h"
#include "klogitem.h"
#include "klogconfig.h"
#include "klogtray.h"

class KLogTray;

class KLogList: public QTlist
{
    Q_OBJECT;

public:
    KLogList(QString, QWidget * = 0);
    virtual ~KLogList();

    void	saveTo(QTextStream &);
    void	printTo(KPrinter &);
    void	thinking(void);
    void	running(void);
    void	markOldPackets();
    ulong 	uncheckedPacketCount;
    ulong	totalPacketCount;

private:
    QString	getLogLine(void);
    void	keyPressEvent(QKeyEvent *);
    bool	addNew(void);
    QString	process(const KLogIP *);

signals:
    void	sigHide(void);
    void	sigShow(bool);
    void	sigExit(void);

private slots:
    void	slotTimer(void);
    void	slotHide(void);
    void	slotClear(void);
    void	slotPause(void);
    void	slotClick(QListViewItem *);
    void	slotOpen(QListViewItem *);
    void	slotExit(void);

private:
    enum	{ THINKING, RUNNING } state;
    int		pauseCount;
    int		showCount;
    int		pollCount;
    ulong	oldestPacket;

    QTimer	*timer;
    QMutex	mutex;
    KLogTail	*tailer;
    KLogConfig	*config;
    KLogTray	*tray;
};

#endif
