/*
 * Klogwatch, Netfilter log monitor
 *
 * Copyright (C) 2004 Nick Battle <nick.battle@freeuk.com>
 *
 * This program is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the
 * Free Software Foundation; either version 2, or (at your option) any
 * later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 */

#include <kfontdialog.h>
#include <qspinbox.h>
#include <qpushbutton.h>
#include <qcheckbox.h>
#include "klogsetup.h"
#include "debug.h"

KLogSetup::KLogSetup(QWidget *parent): QTsetup(parent, 0, true)
{
    pollinterval->setRange(1, 60);
    pauseinterval->setRange(60, 600);
    displayinterval->setRange(0, 60);
    displaylines->setRange(5, 30);
    buffersize->setRange(1000, 100000);

    filename->setText(klogconfig->FILENAME);
    pollinterval->setValue(klogconfig->POLLTIME);
    pauseinterval->setValue(klogconfig->PAUSETIME);
    displayinterval->setValue(klogconfig->SHOWTIME);
    displaylines->setValue(klogconfig->MINLINES);
    buffersize->setValue(klogconfig->BUFFSIZE);
    command->setText(klogconfig->COMMAND);
    fontbutton->setFont(klogconfig->FONT);
    systemtray->setChecked(klogconfig->SYSTRAY == 1);

    if (klogconfig->SYSTRAY == 1)
    {
	trayalert->setChecked(klogconfig->TRAYALERT == 1);
    }
    else
    {
	trayalert->setChecked(0);
	trayalert->setEnabled(false);
    }

    adjustSize();

    connect(OK, SIGNAL(clicked(void)), this, SLOT(okSlot(void)));
    connect(cancel, SIGNAL(clicked(void)), this, SLOT(cancelSlot(void)));
    connect(fontbutton, SIGNAL(clicked(void)), this, SLOT(fontSlot(void)));
    connect(defaults, SIGNAL(clicked(void)), this, SLOT(defaultSlot(void)));
    connect(systemtray, SIGNAL(stateChanged(int)), this, SLOT(traySlot(int)));
    connect(trayalert, SIGNAL(stateChanged(int)), this, SLOT(traySlot(int)));
}

KLogSetup::~KLogSetup()
{
    debug("Destroy KLogSetup\n");
}

void KLogSetup::okSlot()
{
    debug("OK\n");
    klogconfig->FILENAME = filename->text();
    klogconfig->POLLTIME = pollinterval->value();
    klogconfig->PAUSETIME = pauseinterval->value();
    klogconfig->SHOWTIME = displayinterval->value();
    klogconfig->MINLINES = displaylines->value();
    klogconfig->BUFFSIZE = buffersize->value();
    klogconfig->COMMAND = command->text();
    klogconfig->SYSTRAY = (systemtray->isChecked() ? 1 : 0);

    if (klogconfig->SYSTRAY)
	klogconfig->TRAYALERT = (trayalert->isChecked() ? 1 : 0);
    else
	klogconfig->TRAYALERT = 0;

    klogconfig->save();
    accept();
}

void KLogSetup::cancelSlot()
{
    debug("Cancel\n");
    reject();
}

void KLogSetup::fontSlot()
{
    debug("Change Font\n");
    QFont newfont = klogconfig->FONT;
    int rv = KFontDialog::getFont(newfont);

    if (rv == QDialog::Accepted)
    {
    	klogconfig->FONT = newfont;
	fontbutton->setFont(klogconfig->FONT);
	adjustSize();
    }
}

void KLogSetup::defaultSlot()
{
    debug("Setting defaults\n");
    klogconfig->defaults();

    filename->setText(klogconfig->FILENAME);
    pollinterval->setValue(klogconfig->POLLTIME);
    pauseinterval->setValue(klogconfig->PAUSETIME);
    displayinterval->setValue(klogconfig->SHOWTIME);
    displaylines->setValue(klogconfig->MINLINES);
    buffersize->setValue(klogconfig->BUFFSIZE);
    command->setText(klogconfig->COMMAND);
    fontbutton->setFont(klogconfig->FONT);
    systemtray->setChecked(klogconfig->SYSTRAY == 1);
    trayalert->setChecked(klogconfig->TRAYALERT == 1);

    adjustSize();
}

void KLogSetup::traySlot(int state)
{
    debug("Tray state changed\n");

    if (!systemtray->isChecked())
    {
	debug("Clearing tray alert\n");
	trayalert->setChecked(false);
	trayalert->setEnabled(false);
    }
    else
    {
	trayalert->setEnabled(true);
    }
}

// eof
